@@ -42,9 +42,6 @@ Corona::Corona(QObject *parent)
     : QObject(parent)
     , d(new CoronaPrivate(this))
 {
-#ifndef NDEBUG
-    // qCDebug(LOG_PLASMA) << "!!{} STARTUP TIME" << QTime().msecsTo(QTime::currentTime()) << "Corona ctor start";
-#endif
     d->init();
 
 #ifndef NDEBUG
@@ -209,7 +206,7 @@ Containment *Corona::containmentForScreen(int screen, const QString &activity, c
     for (Containment *cont : std::as_const(d->containments)) {
         /* clang-format off */
         if (cont->lastScreen() == screen
-            && (cont->activity().isEmpty() || cont->activity() == activity)
+            && ((cont->activity().isEmpty() || activity.isEmpty()) || cont->activity() == activity)
             && (cont->containmentType() == Plasma::Types::DesktopContainment
                 || cont->containmentType() == Plasma::Types::CustomContainment)) { /* clang-format on */
             containment = cont;
@@ -411,6 +408,10 @@ void Corona::setEditMode(bool edit)
         }
     }
 
+    if (!edit) {
+        requireConfigSync();
+    }
+
     d->editMode = edit;
     Q_EMIT editModeChanged(edit);
 }
@@ -483,7 +484,6 @@ void CoronaPrivate::init()
     lockAction->setAutoRepeat(true);
     lockAction->setIcon(QIcon::fromTheme(QStringLiteral("object-locked")));
     lockAction->setData(Plasma::Types::ControlAction);
-    lockAction->setShortcut(QKeySequence(QStringLiteral("alt+d, l")));
     lockAction->setShortcutContext(Qt::ApplicationShortcut);
 
     // fake containment/applet actions
